This is README content for user

Installation
You can install the Real Python Feed Reader from PyPI:

pip install realpython-reader
The reader is supported on Python 2.7, as well as Python 3.4 and above.
